@@ -1,4 +1,6 @@
 from django.template import Library, TemplateSyntaxError
+from django.utils.translation import ugettext_lazy as _
+
 from tendenci.core.base.template_tags import ListNode, parse_tag_kwargs
 from tendenci.addons.help_files.models import HelpFile
 
@@ -68,15 +70,15 @@ def list_helpfiles(parser, token):
 
     if len(bits) < 3:
         message = "'%s' tag requires more than 3" % bits[0]
-        raise TemplateSyntaxError(message)
+        raise TemplateSyntaxError(_(message))
 
     if bits[1] != "as":
         message = "'%s' second argument must be 'as" % bits[0]
-        raise TemplateSyntaxError(message)
+        raise TemplateSyntaxError(_(message))
 
     kwargs = parse_tag_kwargs(bits)
 
     if 'order' not in kwargs:
         kwargs['order'] = '-create_dt'
 
-    return ListHelpFilesNode(context_var, *args, **kwargs)
\ No newline at end of file
+    return ListHelpFilesNode(context_var, *args, **kwargs)
