@@ -27,7 +27,7 @@ from tendenci.core.base.utils import send_email_notification
 @login_required
 def index(request, template_name="wp_importer/index.html"):
     if "tendenci.addons.articles" not in settings.INSTALLED_APPS:
-        raise MissingApp('Oops, you must install Articles so that we can import your posts from WordPress!')
+        raise MissingApp(_('Oops, you must install Articles so that we can import your posts from WordPress!'))
     if request.method == 'POST':
         form = BlogImportForm(request.POST, request.FILES)
         try:
@@ -59,7 +59,7 @@ def index(request, template_name="wp_importer/index.html"):
                 )
 
         except ValueError:
-            messages.add_message(request, messages.INFO, 'Oops, please login before uploading a blog!')
+            messages.add_message(request, messages.INFO, _('Oops, please login before uploading a blog!'))
             return redirect('auth_login')
 
     else:
